@@ -18,8 +18,9 @@ from Bubot.Core.DataBase.Mongo import Mongo as Storage
 # from bubot.Core.DataBase.SqlLite import SqlLite as Storage
 from Bubot.Core.FastStorage.PythonFastStorage import PythonFastStorage as FastStorage
 from Bubot.Helpers.Helper import Helper
+from Bubot.Helpers.ActionDecorator import async_action
 from Bubot.Helpers.ExtException import ExtException, ResourceNotAvailable
-from Bubot.Core.Ocf import find_drivers
+from Bubot.Ocf.Helper import find_drivers
 import os.path
 
 
@@ -49,7 +50,8 @@ class WebServer(VirtualServer, QueueMixin):
         await self.run_web_server()
         await super().on_pending()
 
-    async def run_web_server(self):
+    @async_action
+    async def run_web_server(self, *, _action):
 
         # self = cls.init_from_file(**kwargs)
         # self.save_config()
@@ -142,7 +144,7 @@ class WebServer(VirtualServer, QueueMixin):
             try:
                 ui_view = self.get_device_class(elem)()
                 if hasattr(ui_view, 'add_route'):
-                    ui_view.add_route(app)
+                    ui_view.add_route(app)  # todo сделать разводящую из всех доступных
                     i += 1
             except Exception as e:
                 self.log.error('Error import_ui_handlers({1}): {0}'.format(e, elem))
